<?php
/**
 * Custom Checkout Fields for WooCommerce - Scripts Class
 *
 * @version 1.3.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_CCF_Scripts' ) ) :

class Alg_WC_CCF_Scripts {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_frontend_scripts' ) );
	}

	/**
	 * enqueue_frontend_scripts.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 * @todo    [dev] (maybe) store `//ajax.googleapis.com/ajax/libs/jqueryui/1.9.0/themes/base/jquery-ui.css` locally
	 */
	function enqueue_frontend_scripts() {
		if ( ! is_checkout() ) {
			return;
		}
		$do_load = array(
			'select2'    => false,
			'datepicker' => false,
			'weekpicker' => false,
			'timepicker' => false,
			'fees'       => false,
		);
		$select2_fields = array();
		$fees_fields    = array();
		for ( $i = 1; $i <= apply_filters( 'alg_wc_ccf_total_fields', 1 ); $i++ ) {
			if ( 'yes' === alg_wc_ccf_get_field_option( 'enabled', $i, 'no' ) ) {
				$field_type = alg_wc_ccf_get_field_option( 'type', $i, 'text' );
				if ( 'select' === $field_type ) {
					if ( 'yes' === alg_wc_ccf_get_field_option( 'type_select_select2', $i, 'no' ) ) {
						$do_load['select2'] = true;
						$select2_fields[] = array(
							'field_id'           => alg_wc_ccf_get_field_option( 'section', $i, 'billing' ) . '_' . ALG_WC_CCF_KEY . '_' . $i,
							'minimumInputLength' => alg_wc_ccf_get_field_option( 'type_select_select2_min_input', $i, 0 ),
							'maximumInputLength' => alg_wc_ccf_get_field_option( 'type_select_select2_max_input', $i, 0 ),
						);
					}
				} elseif ( in_array( $field_type, array( 'datepicker', 'weekpicker', 'timepicker' ) ) ) {
					$do_load[ $field_type ] = true;
				}
				// Fees
				if ( 0 != alg_wc_ccf_get_field_option( 'fee_value', $i, 0 ) ) {
					$do_load['fees'] = true;
					$fees_fields[]   = alg_wc_ccf_get_field_option( 'section', $i, 'billing' ) . '_' . ALG_WC_CCF_KEY . '_' . $i;
				}
			}
		}
		// Select2
		if ( $do_load['select2'] ) {
			wp_enqueue_script( 'alg-wc-ccf-select2',
				alg_wc_custom_checkout_fields()->plugin_url() . '/includes/js/alg-wc-ccf-select2.js',
				array( 'jquery' ),
				ALG_WC_CCF_VERSION,
				true
			);
			wp_localize_script(
				'alg-wc-ccf-select2',
				'alg_wc_ccf_select2',
				array(
					'fields' => $select2_fields,
				)
			);
		}
		// Datepicker & Weekpicker
		if ( $do_load['datepicker'] || $do_load['weekpicker'] ) {
			// Script
			wp_enqueue_script( 'jquery-ui-datepicker' );
			// Style
			wp_enqueue_style( 'jquery-ui-style',
				'//ajax.googleapis.com/ajax/libs/jqueryui/1.9.0/themes/base/jquery-ui.css',
				array(),
				ALG_WC_CCF_VERSION
			);
			// Datepicker script
			if ( $do_load['datepicker'] ) {
				wp_enqueue_script( 'alg-wc-ccf-datepicker',
					alg_wc_custom_checkout_fields()->plugin_url() . '/includes/js/alg-wc-ccf-datepicker.js',
					array( 'jquery' ),
					ALG_WC_CCF_VERSION,
					true
				);
			}
			// Weekpicker script
			if ( $do_load['weekpicker'] ) {
				wp_enqueue_script( 'alg-wc-ccf-weekpicker',
					alg_wc_custom_checkout_fields()->plugin_url() . '/includes/js/alg-wc-ccf-weekpicker.js',
					array( 'jquery' ),
					ALG_WC_CCF_VERSION,
					true
				);
			}
		}
		// Timepicker
		if ( $do_load['timepicker'] ) {
			// Scripts
			wp_enqueue_script( 'jquery-ui-timepicker',
				alg_wc_custom_checkout_fields()->plugin_url() . '/includes/lib/timepicker/jquery.timepicker.min.js',
				array( 'jquery' ),
				ALG_WC_CCF_VERSION,
				true
			);
			wp_enqueue_script( 'alg-wc-ccf-timepicker',
				alg_wc_custom_checkout_fields()->plugin_url() . '/includes/js/alg-wc-ccf-timepicker.js',
				array( 'jquery' ),
				ALG_WC_CCF_VERSION,
				true
			);
			// Style
			wp_enqueue_style( 'alg-wc-ccf-timepicker-style',
				alg_wc_custom_checkout_fields()->plugin_url() . '/includes/lib/timepicker/jquery.timepicker.min.css',
				array(),
				ALG_WC_CCF_VERSION
			);
		}
		// Fees
		if ( $do_load['fees'] ) {
			wp_enqueue_script( 'alg-wc-ccf-fees',
				alg_wc_custom_checkout_fields()->plugin_url() . '/includes/js/alg-wc-ccf-fees.js',
				array( 'jquery' ),
				ALG_WC_CCF_VERSION,
				true
			);
			wp_localize_script( 'alg-wc-ccf-fees',
				'alg_wc_ccf_fees_fields',
				'input[name="' . implode( '"], input[name="', $fees_fields ) . '"]'
			);
		}
	}

}

endif;

return new Alg_WC_CCF_Scripts();
